@@ -30,48 +30,39 @@
 #include "gconf-stock-icons.h"
 #include "gconf-util.h"
 #include <gconf/gconf.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkclipboard.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkhpaned.h>
-#include <gtk/gtkvpaned.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkitemfactory.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmenubar.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkstatusbar.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtktextview.h>
-#include <gtk/gtktreemodelsort.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkvpaned.h>
-#include <gtk/gtklabel.h>
 #include <libintl.h>
 #include <string.h>
 
-#define _(x) gettext (x)
-#define N_(x) (x)
 
 static GObjectClass *parent_class;
 
-static char *
-gconf_editor_window_item_factory_translate_func (const char *path, gpointer func_data)
+static void
+gconf_editor_window_popup_error_dialog (GtkWindow   *parent,
+					const gchar *message,
+					GError      *error)
 {
-	return _(path);
+	GtkWidget *dialog;
+
+	g_return_if_fail (error != NULL);
+
+	dialog = gtk_message_dialog_new (parent,
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_CLOSE,
+					 message,
+					 error->message);
+	g_error_free (error);
+
+	g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_widget_show (dialog);
 }
 
 static void
-gconf_editor_window_close_window (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_window_close_window (GtkAction *action G_GNUC_UNUSED,
+				  GtkWidget *window)
 {
-	GtkWidget *window = callback_data;
-
 	gtk_object_destroy (GTK_OBJECT (window));
 }
 
@@ -124,7 +115,7 @@ gconf_editor_window_go_to (GConfEditorWindow *window,
 }
 
 static void
-gconf_editor_window_copy_key_name (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_window_copy_key_name (GtkAction *action, GtkWidget *callback_data)
 {
 	GConfEditorWindow *window = GCONF_EDITOR_WINDOW (callback_data);
 	char *path;
@@ -155,7 +146,7 @@ gconf_editor_window_copy_key_name (gpointer callback_data, guint action, GtkWidg
 }
 
 static void
-gconf_editor_window_add_bookmark (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_window_add_bookmark (GtkAction *action, GtkWidget *callback_data)
 {
 	GConfEditorWindow *window = GCONF_EDITOR_WINDOW (callback_data);
 	GtkTreeIter iter;
@@ -177,7 +168,7 @@ gconf_editor_window_add_bookmark (gpointer callback_data, guint action, GtkWidge
 }
 
 static void
-gconf_editor_window_edit_bookmarks (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_window_edit_bookmarks (GtkAction *action, GtkWidget *callback_data)
 {
 	static GtkWidget *dialog = NULL;
 
@@ -192,7 +183,7 @@ gconf_editor_window_edit_bookmarks (gpointer callback_data, guint action, GtkWid
 }
 
 static void
-gconf_editor_window_new_window (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_window_new_window (GtkAction *action, GtkWidget *callback_data)
 {
 	GtkWidget *new_window;
 
@@ -201,123 +192,62 @@ gconf_editor_window_new_window (gpointer callback_data, guint action, GtkWidget
 }
 
 static void
-gconf_editor_window_about_window (gpointer callback_data, guint action, GtkWidget *widget)
+help_cb (GtkAction *action, GtkWidget *callback_data)
 {
-	GtkWidget *about_window;
-	GtkWidget *vbox;
-	GtkWidget *label;
-	GtkWidget *image;
-	GdkPixbuf *icon;
-	
-	gchar *markup;
-	
-	about_window = gtk_dialog_new ();
-	gtk_dialog_add_button (GTK_DIALOG (about_window),
-			       GTK_STOCK_OK, GTK_RESPONSE_OK);
-	gtk_dialog_set_default_response (GTK_DIALOG (about_window),
-					 GTK_RESPONSE_OK);
-	
-	gtk_window_set_title (GTK_WINDOW (about_window), _("About GConf-Editor"));
-	icon = gdk_pixbuf_new_from_file (IMAGEDIR"/gconf-editor.png", NULL);
-	if (icon != NULL) {
-		gtk_window_set_icon (GTK_WINDOW (about_window), icon);
-		g_object_unref (icon);
+        GError *error = NULL;
+                                                                                
+        gnome_help_display_desktop (NULL, "gconf-editor", "gconf-editor", NULL, &error);
+                                                                                
+        if (error != NULL) {
+                gconf_editor_window_popup_error_dialog (GTK_WINDOW (GCONF_EDITOR_WINDOW (callback_data)),
+                                                        _("Couldn't display help: %s"), error);
+        }
+}
+
+
+static void
+gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
+{
+	static GtkWidget *about;
+	GdkPixbuf *pixbuf = NULL;
+	const gchar *authors[] = {
+		"Anders Carlsson <andersca@gnome.org>",
+		NULL
+	};
+	const gchar *documenters[] = {
+		"Sun Microsystems",
+		NULL
+	};
+	const gchar *translator_credits = _("translator_credits");
+
+	if (about != NULL) {
+		gtk_window_present (GTK_WINDOW (about));
+		return;
 	}
-	
-	gtk_window_set_resizable (GTK_WINDOW (about_window), FALSE);
-	gtk_window_set_position (GTK_WINDOW (about_window), 
-				 GTK_WIN_POS_CENTER_ON_PARENT);
-	gtk_window_set_type_hint (GTK_WINDOW (about_window), 
-				  GDK_WINDOW_TYPE_HINT_DIALOG);
-	gtk_window_set_transient_for (GTK_WINDOW (about_window), 
-				      GTK_WINDOW (callback_data));
 
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (about_window)->vbox), vbox, FALSE, FALSE, 0);
+	pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+					   "gconf-editor", 48, 0, NULL);
 
-	image = gtk_image_new_from_file (IMAGEDIR"/gconf-editor.png");
-	gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
+	about = gnome_about_new (_("GConf-Editor"), VERSION,
+				 "Copyright \xc2\xa9 2001-2004 Anders Carlsson",
+				 _("An editor for the GConf configuration system."),
+				 authors,
+				 documenters,
+				 strcmp(translator_credits, "translator_credits") != 0 ?  translator_credits : NULL,
+				 pixbuf);
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
 
-	label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
-	markup = g_strdup_printf ("<span size=\"xx-large\" weight=\"bold\">%s "VERSION"</span>\n\n"
-				  "%s\n\n"
-				  "<span size=\"small\">%s</span>\n",
-				  _("GConf-Editor"),
-				  _("An editor for the GConf configuration system."),
-				  "Copyright \xc2\xa9 2001-2004 Anders Carlsson");
-	gtk_label_set_markup (GTK_LABEL (label), markup);
-	g_free (markup);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	
-	gtk_widget_show_all (about_window);
-	gtk_dialog_run (GTK_DIALOG (about_window));
-	gtk_widget_destroy (about_window);
-}
-	
-				
-static GtkItemFactoryEntry menu_items[] =
-{
-	{ N_("/_File"),                        NULL,         0,                                   0, "<Branch>" },
-	{ N_("/File/tearoff1"),                NULL,         NULL,                                0, "<Tearoff>" },
-	{ N_("/File/_New window"),             "<control>N", gconf_editor_window_new_window,      0, "<StockItem>", GTK_STOCK_NEW },
-	{ N_("/File/_Close window"),           "<control>W", gconf_editor_window_close_window,    0, "<StockItem>", GTK_STOCK_CLOSE },
-	{ N_("/File/sep1"),                    NULL,         0,                                   0, "<Separator>" },
-	{ N_("/File/_Quit"),                   "<control>Q", gtk_main_quit,                       0, "<StockItem>", GTK_STOCK_QUIT },
-	{ N_("/_Edit"),                        NULL,         0,                                   0, "<Branch>" },
-	{ N_("/Edit/tearoff2"),                NULL,         NULL,                                0, "<Tearoff>" },
-	{ N_("/Edit/_Copy key name"),          NULL,         gconf_editor_window_copy_key_name,   0, "<StockItem>", GTK_STOCK_COPY },
-	{ N_("/_Bookmarks"),                   NULL,         0,                                   0, "<Branch>", },
-	{ N_("/Bookmarks/tearoff3"),           NULL,         NULL,                                0, "<Tearoff>" },
-	{ N_("/Bookmarks/_Add bookmark"),      NULL,         gconf_editor_window_add_bookmark,    0, "<Item>", },
-	{ N_("/Bookmarks/_Edit bookmarks..."), NULL,         gconf_editor_window_edit_bookmarks,  0, "<Item>", },
-	{ N_("/_Help"),                        NULL,         0,                                   0, "<Branch>" },
-	{ N_("/Help/tearoff4"),                NULL,         NULL,                                0, "<Tearoff>" },
-	{ N_("/Help/_About..."),               NULL,         gconf_editor_window_about_window,    0, "<StockItem>", GCONF_STOCK_ABOUT },
-};
+	g_signal_connect (G_OBJECT (about), "destroy",
+			 G_CALLBACK (gtk_widget_destroyed), &about);
 
-const char *tearoff_paths [] = {
-	N_("/File/tearoff1"),
-	N_("/Edit/tearoff2"),
-	N_("/Bookmarks/tearoff3"),
-	N_("/Help/tearoff4")
-};
+	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (callback_data));
 
-const char *image_menu_items_paths [] = {
-	N_("/File/New window"),
-	N_("/File/Close window"),
-	N_("/File/Quit"),
-	N_("/Edit/Copy key name"),
-	N_("/Help/About...")
-};
+	gtk_widget_show (about);
+}	
 
 static void
-gconf_editor_window_popup_error_dialog (GtkWindow   *parent,
-					const gchar *message,
-					GError      *error)
-{
-	GtkWidget *dialog;
-
-	g_return_if_fail (error != NULL);
-
-	dialog = gtk_message_dialog_new (parent,
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_CLOSE,
-					 message,
-					 error->message);
-	g_error_free (error);
-
-	g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_widget_show (dialog);
-}
-
-static void
-gconf_editor_popup_window_unset_key (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_popup_window_unset_key (GtkAction *action, GtkWidget *callback_data)
 {
 	GConfEditorWindow *window = GCONF_EDITOR_WINDOW (callback_data);
 	GtkTreeIter iter;
@@ -386,7 +316,7 @@ gconf_editor_new_key_response (GtkDialog *editor,
 }
 
 static void
-gconf_editor_popup_window_new_key (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_popup_window_new_key (GtkAction *action, GtkWidget *callback_data)
 {
 	GConfEditorWindow *window = GCONF_EDITOR_WINDOW (callback_data);
 	GtkTreeIter iter;
@@ -449,7 +379,7 @@ gconf_editor_edit_key_response (GtkDialog *editor,
 }
 
 static void
-gconf_editor_popup_window_edit_key (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_popup_window_edit_key (GtkAction *action, GtkWidget *callback_data)
 {
 	GConfEditorWindow *window = GCONF_EDITOR_WINDOW (callback_data);
 	GtkTreeIter iter;
@@ -507,7 +437,7 @@ gconf_editor_window_list_view_row_activated (GtkTreeView       *tree_view,
 					     GtkTreeViewColumn *column,
 					     GConfEditorWindow *window)
 {
-	gconf_editor_popup_window_edit_key (window, 0, NULL);
+	gconf_editor_popup_window_edit_key (NULL, GTK_WIDGET (window));
 }
 
 static gboolean
@@ -547,7 +477,7 @@ gconf_editor_window_row_expanded (GtkTreeView       *tree_view,
 }
 
 static void
-gconf_editor_popup_window_set_as_default (gpointer callback_data, guint action, GtkWidget *widget)
+gconf_editor_popup_window_set_as_default (GtkAction *action, GtkWidget *callback_data)
 {
   GConfEditorWindow *gconfwindow = GCONF_EDITOR_WINDOW (callback_data);
   GtkWindow *window = GTK_WINDOW (callback_data);
@@ -628,19 +558,92 @@ gconf_editor_popup_window_set_as_default (gpointer callback_data, guint action,
   /* TODO: free the schema? */
 }
 
+static GtkActionEntry entries[] = {
+	{ "FileMenu", NULL, N_("_File"), NULL, NULL, NULL },
+	{ "EditMenu", NULL, N_("_Edit"), NULL, NULL, NULL },
+	{ "BookmarksMenu", NULL, N_("_Bookmarks"), NULL, NULL, NULL },
+	{ "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
 
-static GtkItemFactoryEntry popup_menu_items[] = {
-	{ N_("/_New key..."), NULL, gconf_editor_popup_window_new_key,   0, "<StockItem>", GTK_STOCK_NEW },
-	{ N_("/Edit key..."), NULL, gconf_editor_popup_window_edit_key,  1, "<Item>", NULL }, 
-	{ N_("/sep1"),        NULL, 0,                                   0, "<Separator>" },
-	{ N_("/_Unset key"),  NULL, gconf_editor_popup_window_unset_key, 2, "<StockItem>", GTK_STOCK_DELETE },
-	{ N_("/sep2"),        NULL, 0,                                   0, "<Separator>" },
-	{ N_("/Set as _default"),  NULL, gconf_editor_popup_window_set_as_default, 3, "<Item>", NULL },
+	{ "NewWindow", GTK_STOCK_NEW, N_("_New window"), "<control>N", N_("Open a new gconf editor window"), 
+	  G_CALLBACK (gconf_editor_window_new_window) },
+	{ "CloseWindow", GTK_STOCK_CLOSE, N_("_Close window"), "<control>W", N_("Close this window"), 
+	  G_CALLBACK (gconf_editor_window_close_window) },
+	{ "QuitGConfEditor", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q", N_("Quit the gconf editor"), 
+	  G_CALLBACK (gtk_main_quit) },
+	
+	{ "CopyKeyName", GTK_STOCK_COPY, N_("_Copy key name"), "<control>C", N_("Copy the name of the selected key"), 
+	  G_CALLBACK (gconf_editor_window_copy_key_name) },
+	  
+	{ "AddBookmark", NULL, N_("_Add bookmark"), NULL, N_("Add a bookmark to the selected directory"), 
+	  G_CALLBACK (gconf_editor_window_add_bookmark) },
+	{ "EditBookmarks", NULL, N_("_Edit bookmarks"), NULL, N_("Edit the bookmarks"), 
+	G_CALLBACK (gconf_editor_window_edit_bookmarks) },
+	
+	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Open the help contents for the gconf editor"), 
+	  G_CALLBACK (help_cb) },
+	{ "AboutAction", GNOME_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the gconf editor"), 
+	  G_CALLBACK (gconf_editor_window_about_window) },
+
+	{ "NewKey", GTK_STOCK_NEW, N_("_New key..."), "<control>N", N_("Create a new key"),
+	  G_CALLBACK (gconf_editor_popup_window_new_key) },
+	{ "EditKey", NULL, N_("_Edit key..."), NULL, N_("Edit the selected key"),
+	  G_CALLBACK (gconf_editor_popup_window_edit_key) },
+	{ "UnsetKey", GTK_STOCK_DELETE, N_("_Unset key..."), NULL, N_("Unset the selected key"),
+	  G_CALLBACK (gconf_editor_popup_window_unset_key) },
+	{ "DefaultKey", NULL, N_("Set as _default"), NULL, N_("Set the selected key to be the default"),
+	  G_CALLBACK (gconf_editor_popup_window_set_as_default) }	
 };
 
-const char *image_popup_items_paths [] = {
-	N_("/New key..."),
-	N_("/Unset key"),
+static const char *ui_description = 
+	"<ui>"
+	"	<menubar name='GConfEditorMenu'>"
+	"		<menu action='FileMenu'>"
+	"			<menuitem action='NewWindow'/>"
+	"			<menuitem action='CloseWindow'/>"
+	"			<separator/>"
+	"			<menuitem action='QuitGConfEditor'/>"
+	"		</menu>"
+	"		<menu action='EditMenu'>"
+	"			<menuitem action='CopyKeyName'/>"
+	"		</menu>"	
+	"		<menu action='BookmarksMenu'>"
+	"			<menuitem action='AddBookmark'/>"
+	"			<menuitem action='EditBookmarks'/>"
+	"		</menu>"
+	"		<menu action='HelpMenu'>"
+	"			<menuitem action='HelpContents'/>"
+	"			<menuitem action='AboutAction'/>"
+	"		</menu>"
+	"	</menubar>"
+	"	<popup name='GConfKeyPopupMenu'>"
+	"		<menuitem action='NewKey'/>"
+	"		<menuitem action='EditKey'/>"
+	"		<separator/>"
+	"		<menuitem action='UnsetKey'/>"
+	"		<separator/>"
+	"		<menuitem action='DefaultKey'/>"	
+	"	</popup>"
+	"</ui>";
+
+static gchar *image_menu_items_paths[] = {
+	"/GConfEditorMenu/FileMenu/NewWindow",
+	"/GConfEditorMenu/FileMenu/CloseWindow",
+	"/GConfEditorMenu/FileMenu/QuitGConfEditor",
+
+	"/GConfEditorMenu/EditMenu/CopyKeyName",
+
+	"/GConfEditorMenu/HelpMenu/HelpContents",
+	"/GConfEditorMenu/HelpMenu/AboutAction",
+
+	"/GConfKeyPopupMenu/NewKey",
+	"/GConfKeyPopupMenu/UnsetKey"
+};
+
+static gchar *tearoff_paths[] = {
+	"/GConfEditorMenu/FileMenu",
+	"/GConfEditorMenu/EditMenu",
+	"/GConfEditorMenu/BookmarksMenu",
+	"/GConfEditorMenu/HelpMenu"
 };
 
 static void
@@ -706,18 +709,23 @@ list_view_button_press_event (GtkTreeView *tree_view, GdkEventButton *event, GCo
 		if (gtk_tree_view_get_path_at_pos (tree_view, event->x, event->y, &path, NULL, NULL, NULL)) {
 			gtk_tree_selection_select_path (gtk_tree_view_get_selection (tree_view), path);
 
-			gtk_widget_set_sensitive (gtk_item_factory_get_widget_by_action (window->popup_factory, 1), TRUE);
-			gtk_widget_set_sensitive (gtk_item_factory_get_widget_by_action (window->popup_factory, 2), TRUE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/EditKey"), 
+						  TRUE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
+						  TRUE);
 			
 			gtk_tree_path_free (path);
 		}
 		else {
-			gtk_widget_set_sensitive (gtk_item_factory_get_widget_by_action (window->popup_factory, 1), FALSE);
-			gtk_widget_set_sensitive (gtk_item_factory_get_widget_by_action (window->popup_factory, 2), FALSE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/EditKey"), 
+						  FALSE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
+						  FALSE);
+
 		}
 		
-		gtk_item_factory_popup (window->popup_factory, event->x_root, event->y_root,
-					event->button, event->time);
+		gtk_menu_popup (GTK_MENU (window->popup_menu), NULL, NULL, NULL, NULL,
+				event->button, event->time);
 		return TRUE;
 	}
 
@@ -767,16 +775,23 @@ gconf_editor_check_writable (GConfCellRenderer *cell, const gchar *path_str, GCo
 	return ret;
 }
 
+static void
+gconf_editor_window_list_view_popup_position (GtkMenu   *menu G_GNUC_UNUSED,
+					      gint      *x,
+					      gint      *y,
+					      gboolean  *push_in G_GNUC_UNUSED,
+					      GdkWindow *window)
+{
+	gdk_window_get_origin (window, x, y);
+}
+
 static void
 gconf_editor_window_list_view_popup_menu (GtkWidget *widget, GConfEditorWindow *window)
 {
-	int x, y;
-
-	gdk_window_get_origin (widget->window, &x, &y);
-	
-	gtk_item_factory_popup (window->popup_factory, x, y,
-				0, gtk_get_current_event_time ());
-			
+	gtk_menu_popup (GTK_MENU (window->popup_menu), NULL, NULL,
+			(GtkMenuPositionFunc) gconf_editor_window_list_view_popup_position, 
+			widget->window,
+			0, gtk_get_current_event_time ());
 }
 
 static char *
@@ -844,6 +859,7 @@ gconf_editor_window_update_list_selection (GtkTreeSelection *selection, GConfEdi
 		gtk_label_set_text (GTK_LABEL (window->short_desc_label), _("(None)"));
 		gtk_text_buffer_set_text (window->long_desc_buffer, _("(None)"), -1);
 		gtk_widget_hide (window->non_writable_label);
+		gtk_widget_hide (window->no_schema_label);
 		
 		return;
 	}
@@ -893,6 +909,20 @@ gconf_editor_window_update_list_selection (GtkTreeSelection *selection, GConfEdi
 
 	}
 
+	if (schema == NULL) {
+		GConfValue *value = gconf_client_get (client, path, NULL);
+		if (value->type == GCONF_VALUE_SCHEMA) {
+			gtk_widget_hide (window->no_schema_label);
+		}
+		else {
+			gtk_widget_show (window->no_schema_label);
+		}
+		gconf_value_free (value);
+	}
+	else {
+		gtk_widget_hide (window->no_schema_label);
+	}
+
 	gtk_statusbar_pop (GTK_STATUSBAR (window->statusbar), 0);
 	gtk_statusbar_push (GTK_STATUSBAR (window->statusbar), 0, path);
 
@@ -906,9 +936,18 @@ gconf_editor_window_set_have_tearoffs (GConfEditorWindow *window,
 	int i;
 
 	for (i = 0; i < G_N_ELEMENTS (tearoff_paths); i++) {
+		GtkWidget *menu;
 		GtkWidget *item;
+		GList *list;
 
-		item = gtk_item_factory_get_item (window->item_factory, tearoff_paths [i]);
+		item = gtk_ui_manager_get_widget (window->ui_manager, tearoff_paths [i]);
+
+		menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (item));
+		list = gtk_container_get_children (GTK_CONTAINER (menu));
+
+		item = GTK_WIDGET (list->data); 
+		
+		g_list_free (list);
 
 		if (have_tearoffs)
 			gtk_widget_show (item);
@@ -934,14 +973,14 @@ gconf_editor_window_have_tearoffs_notify (GConfClient       *client,
 }
 
 static void
-gconf_editor_window_set_item_has_icon (GtkItemFactory *item_factory,
+gconf_editor_window_set_item_has_icon (GtkUIManager *ui_manager,
 				       const char     *path,
 				       gboolean        have_icons)
 {
 	GtkWidget *item;
 	GtkWidget *image;
 
-	item = gtk_item_factory_get_item (item_factory, path);
+	item = gtk_ui_manager_get_widget (ui_manager, path);
 
 	image = gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (item));
 	if (image && !g_object_get_data (G_OBJECT (item), "gconf-editor-icon"))
@@ -967,10 +1006,7 @@ gconf_editor_window_set_have_icons (GConfEditorWindow *window,
 	int i;
 
 	for (i = 0; i < G_N_ELEMENTS (image_menu_items_paths); i++)
-		gconf_editor_window_set_item_has_icon (window->item_factory, image_menu_items_paths [i], have_icons);
-
-	for (i = 0; i < G_N_ELEMENTS (image_popup_items_paths); i++)
-		gconf_editor_window_set_item_has_icon (window->popup_factory, image_popup_items_paths [i], have_icons);
+		gconf_editor_window_set_item_has_icon (window->ui_manager, image_menu_items_paths [i], have_icons);
 }
 
 static void
@@ -1030,11 +1066,10 @@ gconf_editor_window_finalize (GObject *object)
         GConfEditorWindow *window = (GConfEditorWindow *) object;
 	GConfClient       *client;
 
-	if (window->item_factory)
-		g_object_unref (window->item_factory);
-
 	client = gconf_client_get_default ();
 
+	g_object_unref (window->ui_manager);
+
 	if (window->tearoffs_notify_id)
 		gconf_client_notify_remove (client, window->tearoffs_notify_id);
 
@@ -1063,48 +1098,48 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	GdkPixbuf *icon;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell;
-	GtkAccelGroup *accel_group;      
-	GtkItemFactory *item_factory;
+	GtkAccelGroup *accel_group;
+	GtkActionGroup *action_group;
+	GtkWidget *menubar;
 	GtkTreePath *path;
-	GtkWidget *details_frame, *table, *label, *text_view, *image;
+	GtkWidget *details_frame, *alignment, *table, *label, *text_view, *image;
+	gchar *markup;
+	GError *error;
 	
-	/* Create popup menu */
-	window->popup_factory = gtk_item_factory_new (GTK_TYPE_MENU, "<main>", NULL);
-	gtk_item_factory_set_translate_func (window->popup_factory,
-					     gconf_editor_window_item_factory_translate_func,
-					     NULL, NULL);
-	
-	gtk_item_factory_create_items (window->popup_factory, G_N_ELEMENTS (popup_menu_items),
-				       popup_menu_items, window);
-
 	gtk_window_set_title (GTK_WINDOW (window), _("GConf editor"));
 	gtk_window_set_default_size (GTK_WINDOW (window), 640, 400);
 
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (window), vbox);
-	
-	/* Create menu bar */
-	accel_group = gtk_accel_group_new ();
-	gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
-	g_object_unref (accel_group);
-	
-	item_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, "<main>", accel_group);
-	gtk_item_factory_set_translate_func (item_factory, gconf_editor_window_item_factory_translate_func, NULL, NULL);
 
-	/* Set up item factory to go away with the window */
-	window->item_factory = g_object_ref (item_factory);
-	gtk_object_sink (GTK_OBJECT (item_factory));
+	action_group = gtk_action_group_new ("GConfEditorMenuActions");
+	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), window);
 	
-	/* Create menu items */
-	gtk_item_factory_create_items (item_factory, G_N_ELEMENTS (menu_items),
-				       menu_items, window);
-	gtk_box_pack_start (GTK_BOX (vbox), gtk_item_factory_get_widget (item_factory, "<main>"), FALSE, FALSE, 0);
+	window->ui_manager = gtk_ui_manager_new ();
+	gtk_ui_manager_set_add_tearoffs (window->ui_manager, TRUE);
+	gtk_ui_manager_insert_action_group (window->ui_manager, action_group, 0);
+
+	accel_group = gtk_ui_manager_get_accel_group (window->ui_manager);
+	gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
+
+	error = NULL;
+	if (!gtk_ui_manager_add_ui_from_string (window->ui_manager, ui_description, -1, &error)) {
+      		g_message ("Building menus failed: %s", error->message);
+	      	g_error_free (error);
+      		exit (EXIT_FAILURE);
+    	}
+
+	menubar = gtk_ui_manager_get_widget (window->ui_manager, "/GConfEditorMenu");
+	gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
+
+	window->popup_menu = gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu");
 
 	/* Hook up bookmarks */
 	gconf_bookmarks_hook_up_menu (window,
-				      gtk_item_factory_get_widget (item_factory, "/Bookmarks"),
-				      gtk_item_factory_get_widget (item_factory, "/Bookmarks/Add bookmark"),
-				      gtk_item_factory_get_widget (item_factory, "/Bookmarks/Edit bookmarks..."));
+				      gtk_menu_item_get_submenu (GTK_MENU_ITEM (gtk_ui_manager_get_widget (window->ui_manager,
+				      						     "/GConfEditorMenu/BookmarksMenu/"))),
+				      gtk_ui_manager_get_widget (window->ui_manager, "/GConfEditorMenu/BookmarksMenu/AddBookmark"),
+				      gtk_ui_manager_get_widget (window->ui_manager, "/GConfEditorMenu/BookmarksMenu/EditBookmarks"));
 
 	/* Create content area */
 	hpaned = gtk_hpaned_new ();
@@ -1233,15 +1268,25 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gtk_paned_pack1 (GTK_PANED (vpaned), scrolled_window, TRUE, FALSE);
 
 	/* Create details area */
-	details_frame = gtk_frame_new (_("Key Documentation"));
+	label = gtk_label_new (NULL);
+	markup = g_strdup_printf ("<span weight=\"bold\">%s</span>", _("Key Documentation"));
+	gtk_label_set_markup (GTK_LABEL (label), markup);
+	g_free (markup);
+
+	details_frame = gtk_frame_new (NULL);
+	gtk_frame_set_label_widget (GTK_FRAME (details_frame), label);
+	gtk_frame_set_shadow_type (GTK_FRAME (details_frame), GTK_SHADOW_NONE);
 	gtk_paned_pack2 (GTK_PANED (vpaned), details_frame, FALSE, FALSE);
-	
-	table = gtk_table_new (2, 5, FALSE);
+
+	alignment = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 12, 0, 24, 0);
+	gtk_container_add (GTK_CONTAINER (details_frame), alignment);
+
+	table = gtk_table_new (6, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
 	
-	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
-	gtk_container_add (GTK_CONTAINER (details_frame), table);
+	gtk_container_add (GTK_CONTAINER (alignment), table);
 
 
 	window->non_writable_label = gtk_hbox_new (FALSE, 6);
@@ -1257,49 +1302,62 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (window->non_writable_label), label, FALSE, FALSE, 0);
 	
-	
+
+	window->no_schema_label = gtk_hbox_new (FALSE, 6);
+	gtk_table_attach (GTK_TABLE (table), window->no_schema_label,
+			  0, 2, 1, 2,
+			  GTK_FILL, 0, 0, 0);
+	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show (image);
+	gtk_box_pack_start (GTK_BOX (window->no_schema_label), image, FALSE, FALSE, 0);
+
+	label = gtk_label_new (_("This key has no schema"));
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (window->no_schema_label), label, FALSE, FALSE, 0);
+
+
 	label = gtk_label_new (_("Key Name:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
 	
 	gtk_table_attach (GTK_TABLE (table), label,
-			  0, 1, 1, 2,
+			  0, 1, 2, 3,
 			  GTK_FILL, 0, 0, 0);
 	window->key_name_label = gtk_label_new (_("(None)"));
 	gtk_label_set_selectable (GTK_LABEL (window->key_name_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (window->key_name_label), 0.0, 0.5);	
 	gtk_table_attach (GTK_TABLE (table), window->key_name_label,
-			  1, 2, 1, 2,
+			  1, 2, 2, 3,
 			  GTK_FILL, 0, 0, 0);
 	
 	label = gtk_label_new (_("Key Owner:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);	
 	gtk_table_attach (GTK_TABLE (table), label,
-			  0, 1, 2, 3,
+			  0, 1, 3, 4,
 			  GTK_FILL, 0, 0, 0);
 	window->owner_label= gtk_label_new (_("(None)"));
 	gtk_label_set_selectable (GTK_LABEL (window->owner_label), TRUE);	
 	gtk_misc_set_alignment (GTK_MISC (window->owner_label), 0.0, 0.5);		
 	gtk_table_attach (GTK_TABLE (table), window->owner_label,
-			  1, 2, 2, 3,
+			  1, 2, 3, 4,
 			  GTK_FILL, 0, 0, 0);
 
 	label = gtk_label_new (_("Short Description:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);	
 	gtk_table_attach (GTK_TABLE (table), label,
-			  0, 1, 3, 4,
+			  0, 1, 4, 5,
 			  GTK_FILL, 0, 0, 0);
 	window->short_desc_label= gtk_label_new (_("(None)"));
 	gtk_label_set_line_wrap (GTK_LABEL (window->short_desc_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (window->short_desc_label), TRUE);	
 	gtk_misc_set_alignment (GTK_MISC (window->short_desc_label), 0.0, 0.5);		
 	gtk_table_attach (GTK_TABLE (table), window->short_desc_label,
-			  1, 2, 3, 4,
+			  1, 2, 4, 5,
 			  GTK_FILL, 0, 0, 0);
 
 	label = gtk_label_new (_("Long Description:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.0);	
 	gtk_table_attach (GTK_TABLE (table), label,
-			  0, 1, 4, 5,
+			  0, 1, 5, 6,
 			  GTK_FILL, GTK_FILL, 0, 0);
 
 	window->long_desc_buffer = gtk_text_buffer_new (NULL);
@@ -1317,11 +1375,12 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gtk_container_add (GTK_CONTAINER (scrolled_window), text_view);
 	
 	gtk_table_attach (GTK_TABLE (table), scrolled_window, 
-			  1, 2, 4, 5,
+			  1, 2, 5, 6,
 			  GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 0, 0);
 
 	gtk_widget_show_all (vbox);
 	gtk_widget_hide (window->non_writable_label);
+	gtk_widget_hide (window->no_schema_label);
 	
 	/* Set window icon */
 	icon = gdk_pixbuf_new_from_file (IMAGEDIR"/gconf-editor.png", NULL);
