@@ -20,7 +20,7 @@
 #ifndef __GCONF_EDITOR_WINDOW_H__
 #define __GCONF_EDITOR_WINDOW_H__
 
-#include <gtk/gtkitemfactory.h>
+#include <gtk/gtkuimanager.h>
 #include <gtk/gtkmenu.h>
 #include <gtk/gtktextbuffer.h>
 #include <gtk/gtktreemodel.h>
@@ -50,8 +50,8 @@ struct _GConfEditorWindow {
 	
 	GtkWidget *statusbar;
 
-	GtkItemFactory *popup_factory;
-	GtkItemFactory *item_factory;
+	GtkUIManager *ui_manager;
+	GtkWidget *popup_menu;
 	GtkTreeViewColumn *value_column;
 
 	GtkWidget *non_writable_label;
@@ -59,6 +59,7 @@ struct _GConfEditorWindow {
 	GtkWidget *short_desc_label;
 	GtkTextBuffer *long_desc_buffer;
 	GtkWidget *owner_label;
+	GtkWidget *no_schema_label;
 
 	guint tearoffs_notify_id;
 	guint icons_notify_id;
